@@ -1,4 +1,5 @@
 #' @include generics.R
+#' @importFrom SeuratObject PackageCheck
 #'
 NULL
 
@@ -580,6 +581,7 @@ CellCycleScoring <- function(
 #' \code{ncontrols} most highly expressed features are kept, and the
 #' prefix is kept. All other rows are retained.
 #'
+#' @importFrom utils head
 #' @importFrom Matrix rowSums
 #'
 #' @export
@@ -983,6 +985,27 @@ GroupCorrelation <- function(
   return(object)
 }
 
+#' Load the Annoy index file
+#'
+#' @param object Neighbor object
+#' @param file Path to file with annoy index
+#'
+#' @return Returns the Neighbor object with the index stored
+#' @export
+#' @concept utilities
+#'
+LoadAnnoyIndex <- function(object, file){
+  metric <- slot(object = object, name = "alg.info")$metric
+  ndim <- slot(object = object, name = "alg.info")$ndim
+  if (is.null(x = metric)) {
+    stop("Provided Neighbor object wasn't generated with annoy")
+  }
+  annoy.idx <- CreateAnn(name = metric, ndim = ndim)
+  annoy.idx$load(path.expand(path = file))
+  Index(object = object) <- annoy.idx
+  return(object)
+}
+
 #' Calculate the variance to mean ratio of logged values
 #'
 #' Calculate the variance to mean ratio (VMR) in non-logspace (return answer in
@@ -1081,6 +1104,24 @@ MinMax <- function(data, min, max) {
   return(data2)
 }
 
+#' Calculate the percentage of a vector above some threshold
+#'
+#' @param x Vector of values
+#' @param threshold Threshold to use when calculating percentage
+#'
+#' @return Returns the percentage of \code{x} values above the given threshold
+#'
+#' @export
+#' @concept utilities
+#'
+#' @examples
+#' set.seed(42)
+#' PercentAbove(sample(1:100, 10), 75)
+#'
+PercentAbove <- function(x, threshold) {
+  return(length(x = x[x > threshold]) / length(x = x))
+}
+
 #' Calculate the percentage of all counts that belong to a given set of features
 #'
 #' This function enables you to easily calculate the percentage of all the counts belonging to a
@@ -1412,46 +1453,6 @@ PseudobulkExpression <- function(
   }
 }
 
-#' Load the Annoy index file
-#'
-#' @param object Neighbor object
-#' @param file Path to file with annoy index
-#'
-#' @return Returns the Neighbor object with the index stored
-#' @export
-#' @concept utilities
-#'
-LoadAnnoyIndex <- function(object, file){
-  metric <- slot(object = object, name = "alg.info")$metric
-  ndim <- slot(object = object, name = "alg.info")$ndim
-  if (is.null(x = metric)) {
-    stop("Provided Neighbor object wasn't generated with annoy")
-  }
-  annoy.idx <- CreateAnn(name = metric, ndim = ndim)
-  annoy.idx$load(path.expand(path = file))
-  Index(object = object) <- annoy.idx
-  return(object)
-}
-
-#' Save the Annoy index
-#'
-#' @param object A Neighbor object with the annoy index stored
-#' @param file Path to file to write index to
-#'
-#' @export
-#' @concept utilities
-#'
-SaveAnnoyIndex <- function(
-  object,
-  file
-) {
-  index <- Index(object = object)
-  if (is.null(x = index)) {
-    stop("Index for provided Neighbor object is NULL")
-  }
-  index$save(path.expand(path = file))
-}
-
 #' Regroup idents based on meta.data info
 #'
 #' For cells in each ident, set a new identity based on the most common value
@@ -1483,6 +1484,60 @@ RegroupIdents <- function(object, metadata) {
   return(object)
 }
 
+#' Save the Annoy index
+#'
+#' @param object A Neighbor object with the annoy index stored
+#' @param file Path to file to write index to
+#'
+#' @export
+#' @concept utilities
+#'
+SaveAnnoyIndex <- function(
+  object,
+  file
+) {
+  index <- Index(object = object)
+  if (is.null(x = index)) {
+    stop("Index for provided Neighbor object is NULL")
+  }
+  index$save(path.expand(path = file))
+}
+
+#' Find the Quantile of Data
+#'
+#' Converts a quantile in character form to a number regarding some data.
+#' String form for a quantile is represented as a number prefixed with
+#' \dQuote{q}; for example, 10th quantile is \dQuote{q10} while 2nd quantile is
+#' \dQuote{q2}. Will only take a quantile of non-zero data values
+#'
+#' @param cutoff The cutoff to turn into a quantile
+#' @param data The data to turn find the quantile of
+#'
+#' @return The numerical representation of the quantile
+#'
+#' @importFrom stats quantile
+#'
+#' @export
+#' @concept utilities
+#'
+#' @examples
+#' set.seed(42)
+#' SetQuantile('q10', sample(1:100, 10))
+#'
+SetQuantile <- function(cutoff, data) {
+  if (grepl(pattern = '^q[0-9]{1,2}$', x = as.character(x = cutoff), perl = TRUE)) {
+    this.quantile <- as.numeric(x = sub(
+      pattern = 'q',
+      replacement = '',
+      x = as.character(x = cutoff)
+    )) / 100
+    data <- unlist(x = data)
+    data <- data[data > 0]
+    cutoff <- quantile(x = data, probs = this.quantile)
+  }
+  return(as.numeric(x = cutoff))
+}
+
 #' @rdname UpdateSymbolList
 #'
 #' @return \code{UpdateSymbolList}: \code{symbols} with updated symbols from
@@ -2158,31 +2213,6 @@ Online <- function(url, strict = FALSE, seconds = 5L) {
   return(comp(x = status_code(x = request), y = code))
 }
 
-# Check the existence of a package
-#
-# @param ... Package names
-# @param error If true, throw an error if the package doesn't exist
-#
-# @return Invisibly returns boolean denoting if the package is installed
-#
-PackageCheck <- function(..., error = TRUE) {
-  pkgs <- unlist(x = c(...), use.names = FALSE)
-  package.installed <- vapply(
-    X = pkgs,
-    FUN = requireNamespace,
-    FUN.VALUE = logical(length = 1L),
-    quietly = TRUE
-  )
-  if (error && any(!package.installed)) {
-    stop(
-      "Cannot find the following packages: ",
-      paste(pkgs[!package.installed], collapse = ', '),
-      ". Please install"
-    )
-  }
-  invisible(x = package.installed)
-}
-
 # Parenting parameters from one environment to the next
 #
 # This function allows one to modify a parameter in a parent environment
@@ -2231,17 +2261,6 @@ Parenting <- function(parent.find = 'Seurat', ...) {
   }
 }
 
-# Calculate the percentage of a vector above some threshold
-#
-# @param x Vector of values
-# @param threshold Threshold to use when calculating percentage
-#
-# @return Returns the percentage of `x` values above the given threshold
-#
-PercentAbove <- function(x, threshold) {
-  return(length(x = x[x > threshold]) / length(x = x))
-}
-
 # Generate a random name
 #
 # Make a name from randomly sampled lowercase letters,
@@ -2285,6 +2304,71 @@ RemoveLastField <- function(string, delim = "_") {
   }
 }
 
+# Calculate row mean of a sparse matrix
+# @param mat sparse matrix
+# @return A vector of row mean
+#
+RowMeanSparse <- function(mat) {
+  mat <- RowSparseCheck(mat = mat)
+  output <- row_mean_dgcmatrix(
+    x = slot(object = mat, name = "x"),
+    i = slot(object = mat, name = "i"),
+    rows = nrow(x = mat),
+    cols = ncol(x = mat)
+    )
+  names(x = output) <- rownames(x = mat)
+  return(output)
+}
+
+# Calculate row sum of a sparse matrix
+#
+# @param mat sparse matrix
+# @return A vector of row sum
+#
+RowSumSparse <- function(mat) {
+  mat <- RowSparseCheck(mat = mat)
+  output <- row_sum_dgcmatrix(
+    x = slot(object = mat, name = "x"),
+    i = slot(object = mat, name = "i"),
+    rows = nrow(x = mat),
+    cols = ncol(x = mat)
+  )
+  names(x = output) <- rownames(x = mat)
+  return(output)
+}
+ 
+# Calculate row variance of a sparse matrix
+#
+# @param mat sparse matrix
+# @return A vector of row variance
+#
+RowVarSparse <- function(mat) {
+  mat <- RowSparseCheck(mat = mat)
+  output <- row_var_dgcmatrix(
+    x = slot(object = mat, name = "x"),
+    i = slot(object = mat, name = "i"),
+    rows = nrow(x = mat),
+    cols = ncol(x = mat)
+  )
+  names(x = output) <- rownames(x = mat)
+  return(output)
+}
+
+# Check if the input matrix is dgCMatrix
+#
+# @param mat sparse matrix
+# @return A dgCMatrix
+#
+RowSparseCheck <- function(mat) {
+  if (!inherits(x = mat, what = "sparseMatrix")) {
+    stop("Input should be sparse matrix")
+  } else if (class(x = mat) != "dgCMatrix") {
+    warning("Input matrix is converted to dgCMatrix.")
+    mat <- as.sparse(x = mat)
+  }
+  return(mat)
+}
+
 # Sweep out array summaries
 #
 # Reimplmentation of \code{\link[base]{sweep}} to maintain compatability with
