@@ -304,26 +304,27 @@ test_that("SCTransform wrapper works as expected", {
   expect_equal(fa["MS4A1", "detection_rate"], 0.15)
   expect_equal(fa["MS4A1", "gmean"], 0.2027364, tolerance = 1e-6)
   expect_equal(fa["MS4A1", "variance"], 1.025158, tolerance = 1e-6)
-  expect_equal(fa["MS4A1", "residual_mean"], 0.2362887026, tolerance = 1e-6)
-  expect_equal(fa["MS4A1", "residual_variance"], 2.875760656, tolerance = 1e-6)
+  expect_equal(fa["MS4A1", "residual_mean"], 0.2362887, tolerance = 1e-6)
+  expect_equal(fa["MS4A1", "residual_variance"], 2.875761, tolerance = 1e-6)
 })
 
-object <- suppressWarnings(SCTransform(object = object, ncells = 40, verbose = FALSE))
+suppressWarnings(RNGversion(vstr = "3.5.0"))
+object <- suppressWarnings(SCTransform(object = object, ncells = 40, verbose = FALSE, seed.use =  42))
 test_that("SCTransform ncells param works", {
   expect_true("SCT" %in% names(object))
-  expect_equal(as.numeric(colSums(GetAssayData(object = object[["SCT"]], slot = "scale.data"))[1]), 11.47923, tolerance = 1e6)
+  expect_equal(as.numeric(colSums(GetAssayData(object = object[["SCT"]], slot = "scale.data"))[1]), 12.02126, tolerance = 1e6)
   expect_equal(as.numeric(rowSums(GetAssayData(object = object[["SCT"]], slot = "scale.data"))[5]), 0)
-  expect_equal(as.numeric(colSums(GetAssayData(object = object[["SCT"]], slot = "data"))[1]), 55.42253476, tolerance = 1e-6)
-  expect_equal(as.numeric(rowSums(GetAssayData(object = object[["SCT"]], slot = "data"))[5]), 11.36674295, tolerance = 1e-6)
-  expect_equal(as.numeric(colSums(GetAssayData(object = object[["SCT"]], slot = "counts"))[1]), 119)
-  expect_equal(as.numeric(rowSums(GetAssayData(object = object[["SCT"]], slot = "counts"))[5]), 26)
+  expect_equal(as.numeric(colSums(GetAssayData(object = object[["SCT"]], slot = "data"))[1]), 60.65299, tolerance = 1e-6)
+  expect_equal(as.numeric(rowSums(GetAssayData(object = object[["SCT"]], slot = "data"))[5]), 11.74404, tolerance = 1e-6)
+  expect_equal(as.numeric(colSums(GetAssayData(object = object[["SCT"]], slot = "counts"))[1]), 136)
+  expect_equal(as.numeric(rowSums(GetAssayData(object = object[["SCT"]], slot = "counts"))[5]), 28)
   expect_equal(length(VariableFeatures(object[["SCT"]])), 220)
   fa <- SCTResults(object = object, assay = "SCT", slot = "feature.attributes")
   expect_equal(fa["MS4A1", "detection_rate"], 0.15)
   expect_equal(fa["MS4A1", "gmean"], 0.2027364, tolerance = 1e-6)
   expect_equal(fa["MS4A1", "variance"], 1.025158, tolerance = 1e-6)
-  expect_equal(fa["MS4A1", "residual_mean"], 0.3084931639, tolerance = 1e-6)
-  expect_equal(fa["MS4A1", "residual_variance"], 3.721067314, tolerance = 1e-6)
+  expect_equal(fa["MS4A1", "residual_mean"], 0.2829672, tolerance = 1e-3)
+  expect_equal(fa["MS4A1", "residual_variance"], 3.674079, tolerance = 1e-3)
 })
 
 suppressWarnings(object[["SCT_SAVE"]] <- object[["SCT"]])
